@@ -1,4 +1,4 @@
-/*	$Id: ort-lang-javascript.h,v 1.3 2020/12/17 23:53:29 kristaps Exp $ */
+/*	$Id: ort-lang-javascript.h,v 1.5 2021/05/14 08:21:43 kristaps Exp $ */
 /*
  * Copyright (c) 2020 Kristaps Dzonsons <kristaps@bsd.lv>
  *
@@ -17,8 +17,13 @@
 #ifndef ORT_LANG_JAVASCRIPT_H
 #define ORT_LANG_JAVASCRIPT_H
 
+#define	ORT_LANG_JS_EXPORT	0x01
+#define ORT_LANG_JS_DEFAULT_NS	"ort"
+
 struct	ort_lang_js {
 	const char	*ext_privMethods;
+	const char	*ns;
+	unsigned int	 flags;
 };
 
 int	ort_lang_javascript(const struct config *, 
